'use strict';
const MANIFEST = 'flutter-app-manifest';
const TEMP = 'flutter-temp-cache';
const CACHE_NAME = 'flutter-app-cache';

const RESOURCES = {"assets/AssetManifest.bin": "fae3f527927b80693dff494790a73850",
"assets/AssetManifest.json": "cf553c53bf9d1baa9c4df1cc76960b38",
"assets/assets/fonts/Hamkelasi.ttf": "95f09418149d9c586bbb58c904503297",
"assets/assets/fonts/iransans.ttf": "6e2db50ef0d7f0b5dc03260193bf5237",
"assets/assets/icons/ArrowDown.svg": "07b068936c69620040c7b19b3ee38543",
"assets/assets/icons/ArrowUp.svg": "210c298dd8e664e930212b1adc6ed021",
"assets/assets/icons/edit_icon.svg": "0ff85c397b34665b34ace87d295d3fd6",
"assets/assets/icons/instagram.svg": "7c9220309140b275370674ec70cba37e",
"assets/assets/icons/linkedin.svg": "e841d01daeae235e2f8b9059d8e98cc1",
"assets/assets/icons/notification_icon.svg": "e667165d8930b5f7a6740986be50b5ce",
"assets/assets/icons/telegram.svg": "133df0c3193758722deef9b7e2925029",
"assets/assets/icons/Unlock.svg": "69c2fc02747435ed07531b366ba4171c",
"assets/assets/img/1.jpg": "20c7f40d32bd4b8d106727f193a98246",
"assets/assets/img/background.svg": "da77be2be5a3e12558bd4ed18bc6b089",
"assets/assets/img/EmptyState.svg": "454c733a22adba53e34081619d1786c4",
"assets/assets/img/intro/intro1_img.svg": "df208f4107bfd0fbeb31f57cf9fc13c5",
"assets/assets/img/intro/intro2_img.svg": "b6d498d9724cb7b7eb0917245d6aeb46",
"assets/assets/img/intro/intro3_img.svg": "0127ba1eb642b6842487174984b8dbf6",
"assets/assets/img/intro/intro4_img.svg": "aa2eff0907685eef2bcecda866184530",
"assets/assets/img/logo.svg": "cd53123f14bbdb8092744d3428dad7b2",
"assets/assets/img/logoName.png": "d2024071c0399f7eba8a7bb545074ff0",
"assets/assets/img/sliderDemo_img.png": "95cda73df8f6e6943bac214642a2a611",
"assets/assets/img/welcome1_img.svg": "466d63cd5b842b5f38fbb6721bedb9c4",
"assets/FontManifest.json": "1d12709976207efb31f6dca7504a47e6",
"assets/fonts/MaterialIcons-Regular.otf": "71b3bedc8a7470c6c5e9dc1714371d66",
"assets/NOTICES": "dabed24611dd50902656f6f4eb37ca87",
"assets/packages/cupertino_icons/assets/CupertinoIcons.ttf": "20163ff8b1d491d9ef66bda83888618d",
"assets/shaders/ink_sparkle.frag": "f8b80e740d33eb157090be4e995febdf",
"canvaskit/canvaskit.js": "bbf39143dfd758d8d847453b120c8ebb",
"canvaskit/canvaskit.wasm": "42df12e09ecc0d5a4a34a69d7ee44314",
"canvaskit/chromium/canvaskit.js": "96ae916cd2d1b7320fff853ee22aebb0",
"canvaskit/chromium/canvaskit.wasm": "be0e3b33510f5b7b0cc76cc4d3e50048",
"canvaskit/skwasm.js": "95f16c6690f955a45b2317496983dbe9",
"canvaskit/skwasm.wasm": "1a074e8452fe5e0d02b112e22cdcf455",
"canvaskit/skwasm.worker.js": "51253d3321b11ddb8d73fa8aa87d3b15",
"favicon.png": "ab71c558b119f97b2fc77a157dfeb990",
"firebase-messaging-sw.js": "65900fd31f428a9bb9a7f5d2318fd707",
"flutter.js": "6b515e434cea20006b3ef1726d2c8894",
"icons/Icon-192.png": "9744236eb4e488dc90c9814b028b80ff",
"icons/Icon-512.png": "086e3e6618bd9ffaad67c10610c75327",
"icons/Icon-maskable-192.png": "9744236eb4e488dc90c9814b028b80ff",
"icons/Icon-maskable-512.png": "086e3e6618bd9ffaad67c10610c75327",
"index.html": "15438151572e844ca8798ff5afc0f4db",
"/": "15438151572e844ca8798ff5afc0f4db",
"main.dart.js": "7b2be25896317ba89235490a1c740027",
"manifest.json": "9753a84e3c8412f1f32fb79e29ab057b",
"version.json": "8ceb78e0384694f5a220645ca0183c34"};
// The application shell files that are downloaded before a service worker can
// start.
const CORE = ["main.dart.js",
"index.html",
"assets/AssetManifest.json",
"assets/FontManifest.json"];

// During install, the TEMP cache is populated with the application shell files.
self.addEventListener("install", (event) => {
  self.skipWaiting();
  return event.waitUntil(
    caches.open(TEMP).then((cache) => {
      return cache.addAll(
        CORE.map((value) => new Request(value, {'cache': 'reload'})));
    })
  );
});
// During activate, the cache is populated with the temp files downloaded in
// install. If this service worker is upgrading from one with a saved
// MANIFEST, then use this to retain unchanged resource files.
self.addEventListener("activate", function(event) {
  return event.waitUntil(async function() {
    try {
      var contentCache = await caches.open(CACHE_NAME);
      var tempCache = await caches.open(TEMP);
      var manifestCache = await caches.open(MANIFEST);
      var manifest = await manifestCache.match('manifest');
      // When there is no prior manifest, clear the entire cache.
      if (!manifest) {
        await caches.delete(CACHE_NAME);
        contentCache = await caches.open(CACHE_NAME);
        for (var request of await tempCache.keys()) {
          var response = await tempCache.match(request);
          await contentCache.put(request, response);
        }
        await caches.delete(TEMP);
        // Save the manifest to make future upgrades efficient.
        await manifestCache.put('manifest', new Response(JSON.stringify(RESOURCES)));
        // Claim client to enable caching on first launch
        self.clients.claim();
        return;
      }
      var oldManifest = await manifest.json();
      var origin = self.location.origin;
      for (var request of await contentCache.keys()) {
        var key = request.url.substring(origin.length + 1);
        if (key == "") {
          key = "/";
        }
        // If a resource from the old manifest is not in the new cache, or if
        // the MD5 sum has changed, delete it. Otherwise the resource is left
        // in the cache and can be reused by the new service worker.
        if (!RESOURCES[key] || RESOURCES[key] != oldManifest[key]) {
          await contentCache.delete(request);
        }
      }
      // Populate the cache with the app shell TEMP files, potentially overwriting
      // cache files preserved above.
      for (var request of await tempCache.keys()) {
        var response = await tempCache.match(request);
        await contentCache.put(request, response);
      }
      await caches.delete(TEMP);
      // Save the manifest to make future upgrades efficient.
      await manifestCache.put('manifest', new Response(JSON.stringify(RESOURCES)));
      // Claim client to enable caching on first launch
      self.clients.claim();
      return;
    } catch (err) {
      // On an unhandled exception the state of the cache cannot be guaranteed.
      console.error('Failed to upgrade service worker: ' + err);
      await caches.delete(CACHE_NAME);
      await caches.delete(TEMP);
      await caches.delete(MANIFEST);
    }
  }());
});
// The fetch handler redirects requests for RESOURCE files to the service
// worker cache.
self.addEventListener("fetch", (event) => {
  if (event.request.method !== 'GET') {
    return;
  }
  var origin = self.location.origin;
  var key = event.request.url.substring(origin.length + 1);
  // Redirect URLs to the index.html
  if (key.indexOf('?v=') != -1) {
    key = key.split('?v=')[0];
  }
  if (event.request.url == origin || event.request.url.startsWith(origin + '/#') || key == '') {
    key = '/';
  }
  // If the URL is not the RESOURCE list then return to signal that the
  // browser should take over.
  if (!RESOURCES[key]) {
    return;
  }
  // If the URL is the index.html, perform an online-first request.
  if (key == '/') {
    return onlineFirst(event);
  }
  event.respondWith(caches.open(CACHE_NAME)
    .then((cache) =>  {
      return cache.match(event.request).then((response) => {
        // Either respond with the cached resource, or perform a fetch and
        // lazily populate the cache only if the resource was successfully fetched.
        return response || fetch(event.request).then((response) => {
          if (response && Boolean(response.ok)) {
            cache.put(event.request, response.clone());
          }
          return response;
        });
      })
    })
  );
});
self.addEventListener('message', (event) => {
  // SkipWaiting can be used to immediately activate a waiting service worker.
  // This will also require a page refresh triggered by the main worker.
  if (event.data === 'skipWaiting') {
    self.skipWaiting();
    return;
  }
  if (event.data === 'downloadOffline') {
    downloadOffline();
    return;
  }
});
// Download offline will check the RESOURCES for all files not in the cache
// and populate them.
async function downloadOffline() {
  var resources = [];
  var contentCache = await caches.open(CACHE_NAME);
  var currentContent = {};
  for (var request of await contentCache.keys()) {
    var key = request.url.substring(origin.length + 1);
    if (key == "") {
      key = "/";
    }
    currentContent[key] = true;
  }
  for (var resourceKey of Object.keys(RESOURCES)) {
    if (!currentContent[resourceKey]) {
      resources.push(resourceKey);
    }
  }
  return contentCache.addAll(resources);
}
// Attempt to download the resource online before falling back to
// the offline cache.
function onlineFirst(event) {
  return event.respondWith(
    fetch(event.request).then((response) => {
      return caches.open(CACHE_NAME).then((cache) => {
        cache.put(event.request, response.clone());
        return response;
      });
    }).catch((error) => {
      return caches.open(CACHE_NAME).then((cache) => {
        return cache.match(event.request).then((response) => {
          if (response != null) {
            return response;
          }
          throw error;
        });
      });
    })
  );
}
